@@ -1,6 +1,6 @@
 from checkmytex.analyzed_document import AnalyzedDocument
 from checkmytex.cli.file_printer import FilePrinter
-from checkmytex.cli.overview import OverviewPrinter
+from checkmytex.cli.overview import print_overview
 from checkmytex.cli.problem_handler import InteractiveProblemHandler
 from checkmytex.filtering.whitelist import Whitelist
 from checkmytex.utils.editor import Editor
@@ -21,8 +21,8 @@ class InteractiveCli:
             problem_handler = lambda p: None
         else:
             problem_handler = InteractiveProblemHandler(analyzed_document, self.editor)
-        OverviewPrinter().print(analyzed_document)
+        print_overview(analyzed_document)
         fp = FilePrinter(analyzed_document, problem_handler)
         # Go through all files
-        for f in analyzed_document.list_files():
-            fp.print(f)
+        for file_path in analyzed_document.list_files():
+            fp.print(file_path)
